.. module:: enaml.widgets.frame

===================
enaml.widgets.frame
===================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Border
    Frame


.. autoclass:: Border

.. autoclass:: Frame
